@@ -1,4 +1,6 @@
-{% if not can_replace_view %}
+{% if can_replace_view and not table_exists %}
+CREATE OR REPLACE VIEW {{ table_name }}
+{%- else %}
 {% if table_exists %}
 DROP TABLE IF EXISTS {{ table_name }}{{ ' CASCADE' if needs_cascade else ''}};
 {% elif view_exists %}
@@ -6,8 +8,7 @@ DROP VIEW IF EXISTS {{ table_name }}{{ ' CASCADE' if needs_cascade else ''}};
 {% endif %}
 
 CREATE VIEW {{ table_name }}
-{%- else %}
-CREATE OR REPLACE VIEW {{ table_name }}
+
 {%- endif %}
 
 {%- if select is defined %}
