@@ -2,6 +2,7 @@ from pathlib import Path
 
 from pydantic import BaseModel, FilePath, validator, Extra
 from typing import List, Optional, Union
+from enum import Enum
 from colorama import Fore, Style
 
 from ..core.errors import Ok, Err, Exc
@@ -38,6 +39,22 @@ class Config(BaseModel):
         return Path(values["test_folder"], v)
 
 
+class OnFailValue(str, Enum):
+    skip = "skip"
+    no_skip = "no_skip"
+
+
+class CompileConfig(BaseModel):
+    tags: Optional[List[str]]
+    # sources: Optional[List[str]]
+    # outputs: Optional[List[str]]
+    # parents: Optional[List[str]]
+    # on_fail: Optional[OnFailValue]
+
+    class Config:
+        extra = Extra.forbid
+
+
 class TestTask(Task):
     def config(self, **config):
         self._has_tests = True
@@ -61,11 +78,33 @@ class TestTask(Task):
         except Exception as e:
             return Exc(e)
 
+        self.compiler.update_globals(
+            src=lambda x: self.src(x, connection=self._target_db),
+            config=self.config_macro,
+        )
+
         self.test_query = self.compiler.compile(self.task_config.file_name)
         self.test_query += " LIMIT 5\n"
 
         return Ok()
 
+    def config_macro(self, **config):
+        if self.allow_config:
+            task_config_override = CompileConfig(**config)
+
+            # Sent to the wrapper
+            # if task_config_override.on_fail is not None:
+            #     self._config_input["on_fail"] = task_config_override.on_fail
+
+            if task_config_override.tags is not None:
+                self._config_input["tags"] = task_config_override.tags
+
+            # if task_config_override.parents is not None:
+            #     self._config_input["parents"] = task_config_override.parents
+
+        # Returns an empty string to avoid productin incorrect sql
+        return ""
+
     def setup(self):
         return Ok()
 
@@ -98,11 +137,9 @@ class TestTask(Task):
                     for r in list(res.values()):
                         data.append(r)
                 data = data[:5]
-                values = ", ".join([str(v) for v in data])
+
                 errinfo = f"You can find the compiled test query at compile/{self.group}/{self.name}_test.sql"
-                self.info(
-                    f"{Fore.RED}Please see some values for which the test failed: {Style.BRIGHT}{values}{Style.NORMAL}"
-                )
+
                 return self.fail(errout + errinfo)
             else:
                 return self.fail("Failed test types: custom")
